nbdev-extensions
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

These extensions will have niche use cases in some places, however these
are ones where I find a benefit in having them at least once. Also known
as, cool ideas myself or others have considered with nbdev brought to
life

## Install

``` sh
pip install nbdev-extensions
```

## How to use

`nbdev-extensions` currently has the following features:

- [`new_nb`](https://muellerzr.github.io/nbdev_extensions/mknb.html#new_nb) -
  A CLI/functional interface to quickly generate blank template
  notebooks for nbdev development with all of the necessary boilerplate
  cells prefilled based on the passed parameters.

- [Code Notes](/codenotes) - A note-taking annotation tool utilizing
  nbdev to write quick comments and explanations for sections of code in
  a code cell without cluttering the code cell with comments. These show
  up as panels in the rendered documentation, one with just the source
  code and the other with the source and an explanation
